@@ -273,11 +273,6 @@ class CloudPods:
             # KVM类型服务器配置
             server_config["guest_image_id"] = guest_image_id
             server_config["sku"] = sku
-            # 调度标签配置（排除特定节点）
-            server_config["schedtags"] = [
-                {"id": "094cfe0f-7fbf-451f-879d-d44151539240", "strategy": "exclude"}
-            ]
-
             # 系统盘配置
             storage_medium_type = "ssd"  # 假设存储介质类型为SSD，可根据实际情况调整
             server_config["disks"] = [{
@@ -550,17 +545,17 @@ if __name__ == '__main__':
     # print(rs)
     # rs=cloudpods.host_has_baremetal_server("701f77bf-8cac-4b20-8787-41dc3ddc3f77")
     # print(rs)
-    # rs=cloudpods.get_host_spec("5969cfe2-3a47-4a78-8ed5-36f373199d0f")
-    # print(rs)
-    rs=cloudpods.create_server_by_guest_image("ab370e36-6fd2-49b8-8cbe-d6af6a03d3b2","b193a66d-be6f-49c0-8c19-df43333856db",
-                                              "x86_64",20480,[20],["7ff50bd9-8fbd-4c57-8687-e47933419214"],"demo",hypervisor="baremetal",bios="UEFI",
-                                              storage_type="ssd",
-                                              storage_conf="raid1",
-                                              storage_count=2,
-                                              storage_drive="AdaptecRaid",
-                                              storage_adapter=1
-                                              )
+    rs=cloudpods.get_host_spec("6ff06f38-5806-4d6f-8ad4-d2cf769392fa")
     print(rs)
+    # rs=cloudpods.create_server_by_guest_image("ab370e36-6fd2-49b8-8cbe-d6af6a03d3b2","b193a66d-be6f-49c0-8c19-df43333856db",
+    #                                           "x86_64",20480,[20],["7ff50bd9-8fbd-4c57-8687-e47933419214"],"demo",hypervisor="baremetal",bios="UEFI",
+    #                                           storage_type="ssd",
+    #                                           storage_conf="raid1",
+    #                                           storage_count=2,
+    #                                           storage_drive="AdaptecRaid",
+    #                                           storage_adapter=1
+    #                                           )
+    # print(rs)
     # rs = cloudpods.create_server_by_guest_image("8572ed8a-6ffe-451a-80ac-c04da95e777f",
     #                                             "1fdfbc15-e319-4f59-8e2b-cc45bc3517cb",
     #                                             "x86_64", 20480, [20], ["265005a2-b3a4-42e3-8154-471bdd694487"],
